<tr valign="top" action_del="{{ url.delete }}">
    <td class="ID">
        {{ id }}
    </td>
    <td class="name">
        <p>
            <a href="{{ url.edit }}" title="Edit {{ name }}">
                {{ name }}
            </a>
        </p>
    </td>
    <td class="actions">
        <a href="{{ url.edit }}" id="editButton" class="tableButton">
            Edit
        </a>
        <a href="{{ url.view }}" id="viewButton" class="tableButton">
            View
        </a>
    </td>
    <td class="slug">
        {{ slug }}
    </td>
    <td class="special">
        {{ is_special }}
    </td>
    <td class="delete">
        <a class="deleteButton" href="javascript:void(0)"></a>
    </td>
</tr>