<tr class="productImageRow">
	<td class="thumbnail">
        <img src="{{ thumb }}" width="200" height="150">
    </td>
	<td class="main">
        <input type="hidden" name="photos" value="{{ filename }}"/>
        <input class="radio" type="radio" name="image" value="{{ filename }}">
    </td>
	<td class="order">
        <input class="order" type="text" name="order" value="">
    </td>
    <td class="delete">
        <a class="deleteButton"></a>
    </td>
</tr>