<tr valign="top" action="{{ url.save }}" action_del="{{ url.delete }}">
    <td class="ID">
        {{ reference }}
    </td>
    <td class="thumbnail">
        <a href="{{ url.view }}" title="Link to {{ name }}"><img width="64" height="48" src="{{ url.thumb }}" /></a>
    </td>
    <td class="name"><p class="itemDescription">
            <a href="{{ url.edit }}" title="Link to {{ name }}">
                {{ name }}
            </a>
    </p></td>
    <td class="actions">
        <a href="{{ url.edit }}" id="editButton" class="tableButton">Edit</a>
        <a href="{{ url.view }}" id="viewButton" class="tableButton">View</a></td>
    <td class="views">
        {{ num_views }}
    </td>
    <td class="featured">
        {{{ fields.featured }}}
    </td>
    <td class="sold">
        {{{ fields.sold }}}
    </td>
    <td class="live">
        {{{ fields.live }}}
    </td>
    <td class="category">
        {{{ fields.category }}}
    </td>
    <td class="delete">
        <a class="deleteButton" href="javascript:void(0)"></a>
    </td>
</tr>