<tr valign="top" action_del="{{ url.delete }}">
    <td class="ID">
        {{ id }}
    </td>
    <td class="title"><p class="itemDescription">
        <a href="{{ url.edit }}" title="Edit {{ title }}">
            {{ title }}
        </a>
    </p></td>
    <td class="status">
        {{ status }}
    </td>
    <td class="actions">
        <a href="{{ url.edit }}" id="editButton" class="tableButton">Edit</a>

        <a href="{{ url.view }}" id="viewButton" class="tableButton">View</a>
    </td>
    <td class="delete">
        <a class="deleteButton" href="javascript:void(0)"></a>
    </td>
</tr>