{% extends 'luxuryadmin/base.html' %}
{% load staticfiles %}
{% load thumbnail %}
{% load icanhaz %}
{% block js %}
    {{ block.super }}
    <script src="{% static 'luxuryadmin/js/pages.js'%}"></script>
{% endblock %}
{% block admin_content %}
    {% icanhaz "pageRow" %}
    <ul id="adminBreadcrumbs">
        <li><a href="/admin/collection/" title="">Admin</a></li>
        <li>Manage pages</li>
    </ul>
    {% include 'luxuryadmin/snippets/nav.html' with on='pages' %}
    <h1>Manage pages</h1>
    <div id="tableWrapper">
        <div class="extraOptions">
            <form id="pageSearch" class="tableSearch" action="" method="get">
                <div class="inputPair">
                    <label for="tableSearch"></label>
                    <input type="text" name="tableSearch" id="tableSearch" placeholder="Start typing..." />
                </div>
            </form>
        </div>
        <table class="pages" src="{% url luxuryadmin:xhr_pages %}">
            <colgroup>
                <col class="ID">
                <col class="name" />
                <col class="status" />
                <col class="actions" />
                <col class="delete" />
            </colgroup>
            <thead>
                <tr>
                    <th><a href="#" title="" class="sortData">ID</a></th>
                    <th><a href="#" title="" class="sortData">Title</a></th>
                    <th>Status</th>
                    <th>Actions</th>
                    <th>Del</th>
                </tr>
            </thead>
            <tbody>
            </tbody>
        </table>
    </div>
{% endblock %}