{% extends 'base.html' %}
{% load compress %}
{% load staticfiles %}
{% block css %}
    <link rel="stylesheet" href="{% static 'css/admin.css' %}" type="text/css" />
    <link rel="stylesheet" href="{% static 'css/smoothness/jquery-ui-1.8.23.custom.css' %}" type="text/css" />

{% endblock %}
{% block js %}
        <script type="text/javascript" src="//cdnjs.cloudflare.com/ajax/libs/jqueryui/1.8.21/jquery-ui.min.js"></script>
        <script type="text/javascript" src="https://raw.github.com/radiosilence/jquery-badmanforms/master/jquery.badmanforms.js"></script>


    {% compress js %}
        <script type="text/javascript" src="{% static 'luxuryadmin/js/lux.js' %}"></script>

    {% endcompress %}
{% endblock %}
{% block header %}{% endblock %}
{% block navigation %}{%endblock %}
{% block content %}
	{% block admin_content %}{% endblock %}
{% endblock %}
{% block footer %}{% endblock %}