
    <ul id="primaryAdminNavigation">
        
        <li>
            <a href="{% url luxuryadmin:collection %}" title="Manage hut collection items" class="{% if on == 'collection' %} on{% endif %}">
                Manage Collection
            </a>
        </li>
        
        <li>
            <a href="{% url luxuryadmin:categories %}" title="Manage hut collection categories" class="{% if on == 'categories' %} on{% endif %}">
                Manage Categories
            </a>
        </li>

        <li>
            <a href="{% url luxuryadmin:pages %}" title="Manage static web pages" class="{% if on == 'pages' %} on{% endif %}">
                Manage Pages
            </a>
        </li>
        {% for section in admin.sections %}
        <li>
            <a href="{{ section.url }}" title="{{ section.title }}" class="{% if on_plugin == section.plugin.name and on_section == section.name %} on{% endif %}">
                {{ section.title }}
            </a>
        </li>
        {% endfor %}
    </ul>