{% load thumbnail %}
{% if product %}
	{% for photo in product.photos.all %}
       	<tr class="productImageRow">
       		<td class="thumbnail">
                {% thumbnail photo.image "200x150" crop="center" as im %}<img src="{{ im.url }}" width="200" height="150" />{% endthumbnail %}
            </td>
           	<td class="main">
                <input type="hidden" name="photos" value="{{ photo.image }}"/>
                <input class="radio" type="radio" name="image" value="{{ photo.image }}"{% if photo == product.featured_photo %} checked{% endif %}/>
            </td>
			<td class="order">
                <input class="order" type="text" name="order" value="">
            </td>
           	<td class="delete">
                <a class="deleteButton"></a>
            </td>
       	</tr>
   	{% endfor %}
{% endif %}